internal

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func JSONIntSliceInt

func JSONIntSliceInt(s []JSONInt) []int

func UnmarshalJSONInt

func UnmarshalJSONInt[T ~int](dst *T, data []byte) error

Types

type JSONInt

type JSONInt int

JSONInt is like json.Number for deserializing JSON numbers that are expected to be integers, but may be represented as strings in the JSON. Blank is deserialized as 0.

func IntSliceJSONInt

func IntSliceJSONInt(s []int) []JSONInt

func (JSONInt) Int

func (ji JSONInt) Int() int

func (*JSONInt) UnmarshalJSON

func (ji *JSONInt) UnmarshalJSON(data []byte) error

Jump to